@@ -49,6 +49,7 @@ MainProg::MainProg()
 
 MainProg::~MainProg()
 {
+    kLogPrintf("MainProg::~MainProg()\n");
     gCfg->save();
     delete gsrvlist;
 }
@@ -92,6 +93,8 @@ void MainProg::updatestatuslinecontent()
     {
 	wstatus->setstring(attrYG, " PgUp/PgDn");
 	wstatus->appendstring(attrWG, " Scroll Msg |");
+	wstatus->appendstring(attrYG, " +/-");
+	wstatus->appendstring(attrWG, " Resize Msg |");
 	wstatus->appendstring(attrYG, " Up/Dn");
 	wstatus->appendstring(attrWG, " Select |");
 	if (uistate & stUISELECTOR)
