@@ -20,7 +20,11 @@
 
 #include <string.h>
 #include <stdlib.h>
-#include <form.h>
+#if HAVE_LIBNCURSESW == 1 && NCURSESW_HAVE_SUBDIR == 1
+    #include <ncursesw/form.h>
+#else
+    #include <form.h>
+#endif
 #include "ngroup.h"
 
 
